#!/bin/bash
################################################################################
#
# Intel Data Center Bridging (DCB) Software
# Copyright(c) 2007-2008 Intel Corporation.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms and conditions of the GNU General Public License,
# version 2, as published by the Free Software Foundation.
#
# This program is distributed in the hope it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
#
# The full GNU General Public License is included in this distribution in
# the file called "COPYING".
#
# Contact Information:
# e1000-eedc Mailing List <e1000-eedc@lists.sourceforge.net>
# Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
#
################################################################################

. ./test_fns.sh

usage() {
	echo "Usage: `basename $0` [options (-d:n)] <-d ethX> <peer>"
	echo "      -d  ethX   required option"
	echo "      -n  don't restart dcbd service"
	exit $E_OPTERROR
}

dontrestart=0

E_OPTERROR=65

while getopts ":bd:n" doption
do
	case $doption in
	d) DEVICE=$OPTARG ;;
	n) dontrestart=1 ;;
	*) usage ;;
	esac
done

export dontrestart

if [ "$DEVICE" == "" ]; then
	usage
fi

# fixup compare files with specified device
for i in t[0-9]*
do
	cd $i
	for i in [sg]*
	do
		sed -i -e "s/eth./$DEVICE/g" $i
	done
	cd ..
done

shift $(($OPTIND - 1))

if [ "$1" == "" ]; then
	usage
fi

REMOTE=$1

# run tests
for i in t[0-9]*
do
	echo
	echo RUNNING $i
	cd $i
	./$i.sh $REMOTE $DEVICE
	if [ $? -ne 0 ]; then
		exit 1
	fi
	cd ..

	sleep 2
done
exit 0
